Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions.

Este commit está contenido en:
Alex Voicu
2017-11-29 21:01:28 +00:00
padre b881cf713c
commit d2fd1f5544
Se han modificado 63 ficheros con 173 adiciones y 171 borrados
+1 -1
Ver fichero
@@ -34,7 +34,7 @@ THE SOFTWARE.
#define kernel_name "hello_world"
__global__ void Cpy(hipLaunchParm lp, float *Ad, float* Bd){
int tx = threadIdx.x;
int tx = hipThreadIdx_x;
Bd[tx] = Ad[tx];
}